@@ -110,10 +110,30 @@ def write_logger(text, the_FH, info_type = "info"):
     else:
         pass
 
-def update_logger(the_FH, project_name, app_log_dir, app_version, logger_name):
+def update_logger(the_FH, project_name, app_log_dir, app_version_name, logger_name,update_type = 'day'):
 
-    app_log_file = create_log_file(project_name, app_log_dir, app_version)
-    the_FH.create_logger(app_log_file, logger_name = logger_name)
+    app_log_file = create_log_file(project_name, app_log_dir, version=app_version_name)
+    the_FH.create_logger(app_log_file, logger_name = logger_name,update_type=update_type)
 
 if __name__ == "__main__":
-    pass
\ No newline at end of file
+
+    app_log_dir = "./app_logs"
+    project_name = "expert"
+    logger_name = "inte_triage_expert_in" # 不重要
+    update_type = "min"  # "day"
+    app_version_name = "v1_offline"
+
+    # emr_FH = FileLogger(log_dir = app_log_dir)
+    # emr_FH.create_logger(log_file = app_log_file, logger_name = app_version_name) # 例如: logger_name = "v5_online"
+
+    the_FH = FileLogger(log_dir=app_log_dir, update_type=update_type)
+    app_log_file = create_log_file(project_name, app_log_dir, version=app_version_name)
+    the_FH.create_logger(app_log_file, logger_name=logger_name, update_type=update_type)
+
+    write_logger("创建初始日志,进程pid:%d" % os.getpid(), the_FH, info_type="info")
+
+    for i in range(70):
+
+        update_logger(the_FH, project_name, app_log_dir, app_version_name, logger_name, update_type=update_type)
+        write_logger("count:%d" % (i + 1), the_FH, info_type='info')
+        time.sleep(1)
